@@ -1,4 +1,4 @@
-/* Eye Of Gnome - Image 
+/* Eye Of Gnome - Image
  *
  * Copyright (C) 2007 The Free Software Foundation
  *
@@ -26,10 +26,10 @@
 #include "eog-window.h"
 #include "eog-transform.h"
 #include "eog-image-save-info.h"
+#include "eog-enums.h"
 
 #include <glib.h>
 #include <glib-object.h>
-#include <libgnomevfs/gnome-vfs.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
 #ifdef HAVE_EXIF
@@ -44,6 +44,10 @@
 #include <exempi/xmp.h>
 #endif
 
+#ifdef HAVE_RSVG
+#include <librsvg/rsvg.h>
+#endif
+
 G_BEGIN_DECLS
 
 #ifndef __EOG_IMAGE_DECLR__
@@ -60,18 +64,6 @@ typedef struct _EogImagePrivate EogImagePrivate;
 #define EOG_IS_IMAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),  EOG_TYPE_IMAGE))
 #define EOG_IMAGE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj),  EOG_TYPE_IMAGE, EogImageClass))
 
-typedef enum {
-	EOG_IMAGE_DATA_IMAGE     = 1 << 0,
-	EOG_IMAGE_DATA_DIMENSION = 1 << 1,
-	EOG_IMAGE_DATA_EXIF      = 1 << 2,
-	EOG_IMAGE_DATA_XMP       = 1 << 3
-} EogImageData;
-
-#define EOG_IMAGE_DATA_ALL  (EOG_IMAGE_DATA_IMAGE |     \
-			     EOG_IMAGE_DATA_DIMENSION | \
-			     EOG_IMAGE_DATA_EXIF |      \
-			     EOG_IMAGE_DATA_XMP)
-
 typedef enum {
 	EOG_IMAGE_ERROR_SAVE_NOT_LOCAL,
 	EOG_IMAGE_ERROR_NOT_LOADED,
@@ -92,6 +84,12 @@ typedef enum {
 	EOG_IMAGE_STATUS_FAILED
 } EogImageStatus;
 
+typedef enum {
+  EOG_IMAGE_METADATA_NOT_READ,
+  EOG_IMAGE_METADATA_NOT_AVAILABLE,
+  EOG_IMAGE_METADATA_READY
+} EogImageMetadataStatus;
+
 struct _EogImage {
 	GObject parent;
 
@@ -103,14 +101,19 @@ struct _EogImageClass {
 
 	void (* changed) 	   (EogImage *img);
 
-	void (* size_prepared)     (EogImage *img, 
-				    int       width, 
+	void (* size_prepared)     (EogImage *img,
+				    int       width,
 				    int       height);
 
 	void (* thumbnail_changed) (EogImage *img);
 
-	void (* save_progress)     (EogImage *img, 
+	void (* save_progress)     (EogImage *img,
 				    gfloat    progress);
+
+	void (* next_frame)        (EogImage *img,
+				    gint delay);
+
+	void (* file_changed)      (EogImage *img);
 };
 
 GType	          eog_image_get_type	             (void) G_GNUC_CONST;
@@ -119,43 +122,43 @@ GQuark            eog_image_error_quark              (void);
 
 EogImage         *eog_image_new                      (const char *txt_uri);
 
-EogImage         *eog_image_new_uri                  (GnomeVFSURI *uri);
+EogImage         *eog_image_new_file                 (GFile *file);
 
-gboolean          eog_image_load                     (EogImage   *img, 
+gboolean          eog_image_load                     (EogImage   *img,
 					              EogImageData data2read,
-					              EogJob     *job, 
+					              EogJob     *job,
 					              GError    **error);
 
 void              eog_image_cancel_load              (EogImage   *img);
 
-gboolean          eog_image_has_data                 (EogImage   *img, 
+gboolean          eog_image_has_data                 (EogImage   *img,
 					              EogImageData data);
 
 void              eog_image_data_ref                 (EogImage   *img);
 
 void              eog_image_data_unref               (EogImage   *img);
 
-void              eog_image_set_thumbnail            (EogImage   *img, 
+void              eog_image_set_thumbnail            (EogImage   *img,
 					              GdkPixbuf  *pixbuf);
 
-gboolean          eog_image_save_as_by_info          (EogImage   *img, 
-		      			              EogImageSaveInfo *source, 
-		      			              EogImageSaveInfo *target, 
+gboolean          eog_image_save_as_by_info          (EogImage   *img,
+		      			              EogImageSaveInfo *source,
+		      			              EogImageSaveInfo *target,
 		      			              GError    **error);
 
-gboolean          eog_image_save_by_info             (EogImage   *img, 
-					              EogImageSaveInfo *source, 
+gboolean          eog_image_save_by_info             (EogImage   *img,
+					              EogImageSaveInfo *source,
 					              GError    **error);
 
 GdkPixbuf*        eog_image_get_pixbuf               (EogImage   *img);
 
 GdkPixbuf*        eog_image_get_thumbnail            (EogImage   *img);
 
-void              eog_image_get_size                 (EogImage   *img, 
-					              gint       *width, 
+void              eog_image_get_size                 (EogImage   *img,
+					              gint       *width,
 					              gint       *height);
 
-GnomeVFSFileSize  eog_image_get_bytes                (EogImage   *img);
+goffset           eog_image_get_bytes                (EogImage   *img);
 
 gboolean          eog_image_is_modified              (EogImage   *img);
 
@@ -169,18 +172,15 @@ gpointer          eog_image_get_exif_info            (EogImage   *img);
 
 gpointer          eog_image_get_xmp_info             (EogImage   *img);
 
-GnomeVFSURI*      eog_image_get_uri                  (EogImage   *img);
+GFile*            eog_image_get_file                 (EogImage   *img);
 
 gchar*            eog_image_get_uri_for_display      (EogImage   *img);
 
 EogImageStatus    eog_image_get_status               (EogImage   *img);
 
-void              eog_image_restore_status           (EogImage   *img);
+EogImageMetadataStatus eog_image_get_metadata_status (EogImage   *img);
 
-void              eog_image_set_is_monitored         (EogImage   *img,
-						      gboolean    is_monitored);
-
-void              eog_image_transform                (EogImage   *img, 
+void              eog_image_transform                (EogImage   *img,
 						      EogTransform *trans,
 						      EogJob     *job);
 
@@ -201,6 +201,18 @@ GList		 *eog_image_get_supported_mime_types (void);
 
 gboolean          eog_image_is_supported_mime_type   (const char *mime_type);
 
+gboolean          eog_image_is_animation             (EogImage *img);
+
+gboolean          eog_image_start_animation          (EogImage *img);
+
+#ifdef HAVE_RSVG
+gboolean          eog_image_is_svg                   (EogImage *img);
+RsvgHandle       *eog_image_get_svg                  (EogImage *img);
+EogTransform     *eog_image_get_transform            (EogImage *img);
+#endif
+
+void              eog_image_file_changed             (EogImage *img);
+
 G_END_DECLS
 
 #endif /* __EOG_IMAGE_H__ */
